==> haskell-js-jquery-3.3.1-287-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-js-jquery.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: js-jquery
version: 3.3.1
id: js-jquery-3.3.1-L4FRIfrE6N4G8dHdgPnOVq
key: js-jquery-3.3.1-L4FRIfrE6N4G8dHdgPnOVq
license: MIT
copyright: Neil Mitchell 2014-2018
maintainer: Neil Mitchell <ndmitchell@gmail.com>
author: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://github.com/ndmitchell/js-jquery#readme
synopsis: Obtain minified jQuery code
description:
    This package bundles the minified <http://jquery.com/ jQuery> code into a Haskell package,
    so it can be depended upon by Cabal packages. The first three components of
    the version number match the upstream jQuery version. The package is designed
    to meet the redistribution requirements of downstream users (e.g. Debian).
category: Javascript
abi: a1e8ff77b9bd6bc8286e6af54ef13514
exposed: True
exposed-modules:
    Language.Javascript.JQuery
hidden-modules: Paths_js_jquery
import-dirs: /usr/lib/ghc-8.6.5/site-local/js-jquery-3.3.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/js-jquery-3.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-js-jquery
hs-libraries: HSjs-jquery-3.3.1-L4FRIfrE6N4G8dHdgPnOVq
depends:
    base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-js-jquery/html/js-jquery.haddock
haddock-html: /usr/share/doc/haskell-js-jquery/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-js-jquery-3.3.1-289-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-js-jquery.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: js-jquery
version: 3.3.1
id: js-jquery-3.3.1-JOkgkdGpWa36fkwsiViWz4
key: js-jquery-3.3.1-JOkgkdGpWa36fkwsiViWz4
license: MIT
copyright: Neil Mitchell 2014-2018
maintainer: Neil Mitchell <ndmitchell@gmail.com>
author: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://github.com/ndmitchell/js-jquery#readme
synopsis: Obtain minified jQuery code
description:
    This package bundles the minified <http://jquery.com/ jQuery> code into a Haskell package,
    so it can be depended upon by Cabal packages. The first three components of
    the version number match the upstream jQuery version. The package is designed
    to meet the redistribution requirements of downstream users (e.g. Debian).
category: Javascript
abi: 4265c8f463d7d9621143048cbfd1f829
exposed: True
exposed-modules:
    Language.Javascript.JQuery
hidden-modules: Paths_js_jquery
import-dirs: /usr/lib/ghc-8.6.5/site-local/js-jquery-3.3.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/js-jquery-3.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-js-jquery
hs-libraries: HSjs-jquery-3.3.1-JOkgkdGpWa36fkwsiViWz4
depends:
    base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-js-jquery/html/js-jquery.haddock
haddock-html: /usr/share/doc/haskell-js-jquery/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
